/*!
 * @file        main.h
 *
 * @brief       Header for main.c module
 *
 * @version     V1.0.3
 *
 * @date        2023-07-31
 *
 * @attention
 *
 *  Copyright (C) 2021-2023 Geehy Semiconductor
 *
 *  You may not use this file except in compliance with the
 *  GEEHY COPYRIGHT NOTICE (GEEHY SOFTWARE PACKAGE LICENSE).
 *
 *  The program is only for reference, which is distributed in the hope
 *  that it will be useful and instructional for customers to develop
 *  their software. Unless required by applicable law or agreed to in
 *  writing, the program is distributed on an "AS IS" BASIS, WITHOUT
 *  ANY WARRANTY OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the GEEHY SOFTWARE PACKAGE LICENSE for the governing permissions
 *  and limitations under the License.
 */

/* Define to prevent recursive inclusion */
#ifndef __MAIN_H
#define __MAIN_H

#ifdef __cplusplus
  extern "C" {
#endif

/* Includes */
#include "apm32f4xx.h"
#include "apm32f4xx_gpio.h"
#include "apm32f4xx_fmc.h"
#include "apm32f4xx_usart.h"
#include "apm32f4xx_misc.h"

#include "bsp_usart.h"
#include "bsp_flash.h"
#include "common.h"
#include "ymodem.h"
#include "menu.h"

/** @addtogroup Examples
  @{
  */

/** @addtogroup IAP_BootLoader
  @{
  */

/** @defgroup IAP_BootLoader_Functions Functions
  @{
  */

#define Jump_to_APP1()  FMC_Lock();\
                        JumpAddress = *(__IO uint32_t *) (USER_APP1_ADDRESS + 4);\
                        Jump_To_Application = (pFunction) JumpAddress;\
                        __set_MSP(*(__IO uint32_t *) USER_APP1_ADDRESS);\
                        Jump_To_Application();

#define Jump_to_APP2()  FMC_Lock();\
                        JumpAddress = *(__IO uint32_t *) (USER_APP2_ADDRESS + 4);\
                        Jump_To_Application = (pFunction) JumpAddress;\
                        __set_MSP(*(__IO uint32_t *) USER_APP2_ADDRESS);\
                        Jump_To_Application();

#define Jump_to_App(Application)    if(Application == APP1){\
                                    Jump_to_APP1();}\
                                    else{\
                                    Jump_to_APP2();}

/**@} end of group IAP_BootLoader_Functions */

/** @defgroup IAP_BootLoader_Functions Functions
  @{
  */

/*!
 * @brief    function hook
 */
typedef  void (*pFunction)(void);

/** extern variables*/
extern volatile pFunction Jump_To_Application;
extern __IO uint32_t JumpAddress;

/** function declaration*/
void Delay(uint32_t count);
void SetJumpAddress(uint32_t Application);
#ifdef __cplusplus
}
#endif

#endif /* __MAIN_H */

/**@} end of group IAP_BootLoader_Functions */
/**@} end of group IAP_BootLoader */
/**@} end of group Examples */
