/*!
 * @file        main.c
 *
 * @brief       Main program body
 *
 * @version     V1.0.3
 *
 * @date        2023-07-31
 *
 * @attention
 *
 *  Copyright (C) 2021-2023 Geehy Semiconductor
 *
 *  You may not use this file except in compliance with the
 *  GEEHY COPYRIGHT NOTICE (GEEHY SOFTWARE PACKAGE LICENSE).
 *
 *  The program is only for reference, which is distributed in the hope
 *  that it will be useful and instructional for customers to develop
 *  their software. Unless required by applicable law or agreed to in
 *  writing, the program is distributed on an "AS IS" BASIS, WITHOUT
 *  ANY WARRANTY OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the GEEHY SOFTWARE PACKAGE LICENSE for the governing permissions
 *  and limitations under the License.
 */

/* Includes */
#include "main.h"
#include "bsp_usart.h"
#include "bsp_flash.h"
#include "Board.h"
#include <stdio.h>

/** @addtogroup Examples
  @{
  */

/** @addtogroup IAP_BootLoader
  @{
  */

/** @defgroup IAP_BootLoader_Macros Macros
  @{
  */
#ifdef APM32F411
#define APM_LEDInit  APM_TINY_LEDInit
#define APM_LEDOn    APM_TINY_LEDOn
#else
#define APM_LEDInit  APM_MINI_LEDInit
#define APM_LEDOn    APM_MINI_LEDOn
#endif

/**@} end of group IAP_BootLoader_Macros */

/** @defgroup IAP_BootLoader_Functions Functions
  @{
  */

__IO uint32_t JumpAddress;
volatile pFunction Jump_To_Application;


/*!
 * @brief       Main program
 *
 * @param       None
 *
 * @retval      None
 */
int main(void)
{
    /* Initialize LED on APM32F4xx MINI Board */
    APM_LEDInit(LED2);
    APM_LEDInit(LED3);

    /* Initialize UART mounted on APM32F4xx MINI Board */
    USART1_Init(115200);

    APM_LEDOn(LED2);
    APM_LEDOn(LED3);
    
    /* Configure the Flash to re-program the Flash */
    FLASH_IAP_Init();
    
    /* Display Select menu */
    Select_Menu();

    /* Jump to user application 1 */
    SendString(">> Jump to user application 1\r\n");

    Jump_to_App(APP1);

    
    while (1)
    {
    }
}

/*!
 * @brief       Delay
 *
 * @param       count:  delay count
 *
 * @retval      None
 */
void Delay(uint32_t count)
{
    volatile uint32_t delay = count;
    while(delay--);
}

/**@} end of group IAP_BootLoader_Functions */
/**@} end of group IAP_BootLoader */
/**@} end of group Examples */
