/*!
 * @file        main.c
 *
 * @brief       Main program body
 *
 * @version     V1.0.0
 *
 * @date        2023-07-31
 *
 * @attention
 *
 *  Copyright (C) 2021-2023 Geehy Semiconductor
 *
 *  You may not use this file except in compliance with the
 *  GEEHY COPYRIGHT NOTICE (GEEHY SOFTWARE PACKAGE LICENSE).
 *
 *  The program is only for reference, which is distributed in the hope
 *  that it will be useful and instructional for customers to develop
 *  their software. Unless required by applicable law or agreed to in
 *  writing, the program is distributed on an "AS IS" BASIS, WITHOUT
 *  ANY WARRANTY OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the GEEHY SOFTWARE PACKAGE LICENSE for the governing permissions
 *  and limitations under the License.
 */

/* Includes */
#include "board.h"
#include "apm32f4xx.h"
#include "flash.h"
#include "main.h"
#include <string.h>

/** @addtogroup Examples
  @{
  */

/** @addtogroup QSPI_QualSPI
  @{
  */ 

/** @defgroup QSPI_QualSPI_Enumeration Enumeration
  @{
*/

enum
{
    PASSED,
    FAILED
};

/**@} end of group QSPI_QualSPI_Enumeration */

/** @defgroup QSPI_QualSPI_Functions Functions
  @{
*/

void Delay(void);

/*!
 * @brief       Main program
 *
 * @param       None
 *
 * @retval      None
 *
 */
int main(void)
{
    volatile uint16_t flashID = 0;

    APM_TINY_LEDInit(LED2);
    APM_TINY_LEDInit(LED3);

    FLASH_Init();

    while(1)
    {
        flashID = FLASH_ReadID();
        if(flashID != 0)
        {
            break;
        }
        Delay();
        APM_TINY_LEDToggle(LED2);
    }

    while(1)
    {
        if(FLASH_ReadWriteTest() == FAILED)
        {
            Delay();
            APM_TINY_LEDToggle(LED2);
        }
        else
        {
            break;
        }
    }

    while(1)
    {
        Delay();
        APM_TINY_LEDToggle(LED3);
    }

}

/*!
 * @brief       Main program
 *
 * @param       None
 *
 * @retval      None
 *
 */
void Delay(void)
{
    volatile uint32_t delay = 0xfffff * 5;

    while (delay--);
}

/**@} end of group QSPI_QualSPI_Functions */
/**@} end of group QSPI_QualSPI */
/**@} end of group Examples */
